@@ -63,6 +63,12 @@ func (s *Action) recipientsList(ctx context.Context) []string {
 // completion.
 func (s *Action) RecipientsComplete(c *cli.Context) {
 	ctx := ctxutil.WithGlobalFlags(c)
+	if err := s.IsInitialized(c); err != nil {
+		debug.Log("IsInitialized returned error: %s", err)
+
+		return
+	}
+
 	for _, v := range s.recipientsList(ctx) {
 		fmt.Fprintln(stdout, v)
 	}
@@ -98,6 +104,8 @@ func (s *Action) RecipientsAdd(c *cli.Context) error {
 	// select recipient.
 	recipients := c.Args().Slice()
 	if len(recipients) < 1 {
+		out.Notice(ctx, "Fetching available recipients. Please wait...")
+
 		debug.Log("no recipients given, asking for selection")
 		r, err := s.recipientsSelectForAdd(ctx, store)
 		if err != nil {
