@@ -20,11 +20,12 @@ import (
 	"github.com/gopasspw/gopass/pkg/ctxutil"
 	"github.com/gopasspw/gopass/pkg/debug"
 	"github.com/urfave/cli/v2"
+	"github.com/xhit/go-str2duration"
 )
 
 var (
-	autosyncIntervalDays = 3
-	autosyncLastRun      time.Time
+	autosyncInterval = time.Duration(3*24) * time.Hour
+	autosyncLastRun  time.Time
 )
 
 func init() {
@@ -40,7 +41,7 @@ func init() {
 		return
 	}
 
-	autosyncIntervalDays = iv
+	autosyncInterval = time.Duration(iv*24) * time.Hour
 }
 
 // Sync all stores with their remotes.
@@ -69,13 +70,21 @@ func (s *Action) autoSync(ctx context.Context) error {
 
 	ls := s.rem.LastSeen("autosync")
 	debug.Log("autosync - last seen: %s", ls)
-	syncInterval := autosyncIntervalDays
+	syncInterval := autosyncInterval
 
-	if s.cfg.IsSet("autosync.interval") {
-		syncInterval = s.cfg.GetInt("autosync.interval")
+	if intervalStr := s.cfg.Get("autosync.interval"); intervalStr != "" {
+		if _, err := strconv.Atoi(intervalStr); err == nil {
+			intervalStr += "d"
+		}
+		if duration, err := str2duration.Str2Duration(intervalStr); err != nil {
+			out.Warningf(ctx, "failed to parse autosync.interval %q: %q", intervalStr, err)
+		} else {
+			syncInterval = duration
+		}
 	}
+	debug.Log("autosync - interval: %s", syncInterval)
 
-	if time.Since(ls) > time.Duration(syncInterval)*24*time.Hour {
+	if time.Since(ls) > syncInterval {
 		err := s.sync(ctx, "")
 		if err != nil {
 			autosyncLastRun = time.Now()
