@@ -4,13 +4,14 @@ import (
 	"context"
 	"testing"
 
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/stretchr/testify/require"
 )
 
 func TestEncrypt(t *testing.T) {
 	t.Parallel()
 
-	ctx, cancel := context.WithCancel(context.Background())
+	ctx, cancel := context.WithCancel(config.NewContextInMemory())
 
 	g := &GPG{}
 	g.binary = "rundll32"
@@ -23,7 +24,7 @@ func TestEncrypt(t *testing.T) {
 func TestDecrypt(t *testing.T) {
 	t.Parallel()
 
-	ctx, cancel := context.WithCancel(context.Background())
+	ctx, cancel := context.WithCancel(config.NewContextInMemory())
 
 	g := &GPG{}
 	g.binary = "rundll32"
@@ -36,7 +37,7 @@ func TestDecrypt(t *testing.T) {
 func TestGenerateIdentity(t *testing.T) {
 	t.Parallel()
 
-	ctx, cancel := context.WithCancel(context.Background())
+	ctx, cancel := context.WithCancel(config.NewContextInMemory())
 
 	g := &GPG{}
 	g.binary = "rundll32"
