@@ -1,11 +1,11 @@
 package fs
 
 import (
-	"context"
 	"os"
 	"path/filepath"
 	"testing"
 
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -15,7 +15,7 @@ func TestSetAndGet(t *testing.T) {
 
 	initialContent := []byte(`initial file content`)
 	otherContent := []byte(`other file content`)
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	path := t.TempDir()
 
@@ -49,7 +49,7 @@ func TestMove(t *testing.T) {
 
 	initialContent := []byte(`initial file content`)
 	otherContent := []byte(`other file content`)
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	path := t.TempDir()
 
@@ -242,7 +242,7 @@ func TestDelete(t *testing.T) {
 			store := &Store{
 				path,
 			}
-			err := store.Delete(context.Background(), filepath.Join(test.toDelete...))
+			err := store.Delete(config.NewContextInMemory(), filepath.Join(test.toDelete...))
 
 			if test.shouldErr {
 				if err == nil {
