@@ -2,12 +2,12 @@ package leaf
 
 import (
 	"bytes"
-	"context"
 	"os"
 	"testing"
 
 	"github.com/gopasspw/gopass/internal/backend/crypto/plain"
 	"github.com/gopasspw/gopass/internal/backend/storage/fs"
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/gopasspw/gopass/internal/out"
 	"github.com/gopasspw/gopass/internal/recipients"
 	"github.com/gopasspw/gopass/pkg/gopass/secrets"
@@ -18,7 +18,7 @@ import (
 func TestFsck(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = WithCheckRecipients(ctx, false)
 
 	obuf := &bytes.Buffer{}
