@@ -24,6 +24,22 @@ type Config struct {
 	vars     map[string][]string
 }
 
+// IsEmpty returns true if the config is empty (typically a newly initialized config, but still unused).
+// Since gitconfig.New() already sets the global path to the globalConfigFile() one, we cannot rely on
+// the path being set to checki this. We need to check the  raw length to be sure it wasn't just
+// the default empty config struct.
+func (c *Config) IsEmpty() bool {
+	if c == nil || c.vars == nil {
+		return true
+	}
+
+	if c.raw.Len() > 0 {
+		return false
+	}
+
+	return true
+}
+
 // Unset deletes a key.
 func (c *Config) Unset(key string) error {
 	if c.readonly {
@@ -130,7 +146,7 @@ func (c *Config) Set(key, value string) error {
 }
 
 func (c *Config) insertValue(key, value string) error {
-	debug.Log("input (%s: %s): ---------\n%s\n-----------\n", key, value, c.raw.String())
+	debug.Log("input (%s: %s): \n--------------\n%s\n--------------\n", key, value, strings.Join(strings.Split("- "+c.raw.String(), "\n"), "\n- "))
 
 	wSection, wSubsection, wKey := splitKey(key)
 
@@ -188,7 +204,7 @@ func (c *Config) insertValue(key, value string) error {
 	c.raw.WriteString(strings.Join(lines, "\n"))
 	c.raw.WriteString("\n")
 
-	debug.Log("output: ---------\n%s\n-----------\n", c.raw.String())
+	debug.Log("output: \n--------------\n%s\n--------------\n", strings.Join(strings.Split("+ "+c.raw.String(), "\n"), "\n+ "))
 
 	return c.flushRaw()
 }
@@ -215,7 +231,7 @@ func parseSectionHeader(line string) (section, subsection string, skip bool) { /
 // rewriteRaw is used to rewrite the raw config copy. It is used for set and unset operations
 // with different callbacks each.
 func (c *Config) rewriteRaw(key, value string, cb parseFunc) error {
-	debug.Log("input (%s: %s): ---------\n%s\n-----------\n", key, value, c.raw.String())
+	debug.Log("input (%s: %s): \n--------------\n%s\n--------------\n", key, value, strings.Join(strings.Split("- "+c.raw.String(), "\n"), "\n- "))
 
 	lines := parseConfig(strings.NewReader(c.raw.String()), key, value, cb)
 
@@ -223,7 +239,7 @@ func (c *Config) rewriteRaw(key, value string, cb parseFunc) error {
 	c.raw.WriteString(strings.Join(lines, "\n"))
 	c.raw.WriteString("\n")
 
-	debug.Log("output: ---------\n%s\n-----------\n", c.raw.String())
+	debug.Log("output: \n--------------\n%s\n--------------\n", strings.Join(strings.Split("+ "+c.raw.String(), "\n"), "\n+ "))
 
 	return c.flushRaw()
 }
@@ -239,7 +255,7 @@ func (c *Config) flushRaw() error {
 		return err
 	}
 
-	debug.Log("writing config to %s: -----------\n%s\n--------------", c.path, c.raw.String())
+	debug.Log("writing config to %s: \n--------------\n%s\n--------------", c.path, c.raw.String())
 
 	if err := os.WriteFile(c.path, []byte(c.raw.String()), 0o600); err != nil {
 		return fmt.Errorf("failed to write config to %s: %w", c.path, err)
