@@ -7,6 +7,7 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/gopasspw/gopass/internal/out"
 	"github.com/gopasspw/gopass/pkg/ctxutil"
 	"github.com/stretchr/testify/assert"
@@ -23,7 +24,7 @@ func TestAskForString(t *testing.T) {
 		Stderr = os.Stderr
 	}()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithAlwaysYes(ctx, true)
 
 	sv, err := AskForString(ctx, "test", "foobar")
@@ -70,7 +71,7 @@ func TestAskForBool(t *testing.T) {
 		Stderr = os.Stderr
 	}()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithAlwaysYes(ctx, true)
 
 	bv, err := AskForBool(ctx, "test", false)
@@ -127,7 +128,7 @@ func TestAskForInt(t *testing.T) {
 		Stderr = os.Stderr
 	}()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithAlwaysYes(ctx, true)
 
 	got, err := AskForInt(ctx, "test", 42)
@@ -160,7 +161,7 @@ func TestAskForConfirmation(t *testing.T) {
 		Stderr = os.Stderr
 	}()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithAlwaysYes(ctx, true)
 	assert.True(t, AskForConfirmation(ctx, "test"))
 
@@ -190,7 +191,7 @@ func TestAskForKeyImport(t *testing.T) {
 		Stderr = os.Stderr
 	}()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithAlwaysYes(ctx, true)
 
 	assert.True(t, AskForKeyImport(ctx, "test", []string{}))
@@ -219,7 +220,7 @@ func TestAskForPasswordNonInteractive(t *testing.T) {
 		Stderr = os.Stderr
 	}()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithInteractive(ctx, false)
 
 	_, err := AskForPassword(ctx, "test", true)
@@ -260,7 +261,7 @@ func TestAskForPasswordInteractive(t *testing.T) {
 		Stderr = os.Stderr
 	}()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	askFn := func(ctx context.Context, prompt string) (string, error) {
 		return "test", nil
 	}
